(function(Drupal, drupalSettings) {
  Drupal.behaviors.sessionReminderModal = {
    attach: function () {
      // Dismiss any current timeout notifications across all tabs
      CloseModal();

      // Retrieve settings for notification timing
      const notifyBeforeSeconds = parseInt(drupalSettings.session_reminder.timeout_notifier.warning_threshold);
      const expTimestamp = drupalSettings.session_reminder.timeout_notifier.session_expire_timestamp;

      // Get DOM elements for the alert container and alert components
      const container = document.getElementById('sr--modal-form-container');
      const alert = document.getElementById('sr--modal-form');
      const closeBtn = alert.querySelector('.sr--modal-form--close-btn');
      const refreshBtn = alert.querySelector('.sr--modal-form--refresh-btn');
      const alertBody = alert.querySelector('.sr--modal-form--description');
      const alertTitle = alert.querySelector('.sr--modal-form--title');
      const cancelBtn = alert.querySelector('.sr--modal-form--cancel');

      // Flags to track the state of the alerts
      let alertDisplayed = false;
      let expireAlertDisplayed = false;

      // Runs every second to check session timeout and notify the user
      setInterval(function() {
        const currentTimestamp = Math.floor(new Date().getTime() / 1000);
        const notificationTriggerTimestamp = expTimestamp - notifyBeforeSeconds;
        const timeLeft = expTimestamp - currentTimestamp;
        const modalClosed = parseInt(localStorage.getItem('sr__modal_form__closed'));

        console.log('timeLeft: ' + timeLeft);

        if (!modalClosed){
          if (currentTimestamp >= expTimestamp) {
            // If the session has expired
            if (!expireAlertDisplayed)  {
              alertTitle.innerText = Drupal.t('Session Expired');
              alertBody.innerText = Drupal.t("You need to log in again to access the platform!");
              closeBtn.style.display = "inline-block";
              refreshBtn.style.display = "none";
              container.style.display = 'block';
              expireAlertDisplayed = true;
            }
          } else if (currentTimestamp >= notificationTriggerTimestamp) {
            // If the session is about to expire (less than notifyBeforeSeconds)
            alertBody.innerText = Drupal.t(`Your session will expire in @sec seconds.`,{'@sec':timeLeft.toString()});
            if (!alertDisplayed) {
              container.style.display = 'block';
              alertDisplayed = true;
            }
          } else {
            // Reset alert display when the session is not yet close to expiry
            alertDisplayed = false;
          }
        }

        // If any tab has dismissed the notification, hide it
        if (modalClosed) {
          container.style.display = 'none';
        }

      }, 1000);

      // Attach action to the cancel button to dismiss the notification
      cancelBtn.onclick = () => {
        CloseModal();
      };

      // Function to dismiss the notification and sync across all tabs
      function CloseModal() {
        // Mark the notification as dismissed in localStorage
        localStorage.setItem('sr__modal_form__closed', '1');
        setTimeout(() => {
          // After 1 second, reset the dismissal flag, allowing other tabs to show the notification again
          localStorage.setItem('sr__modal_form__closed', '0');
        }, 1000);
      }
    }
  };
})(Drupal, drupalSettings);
