<?php

namespace Drupal\session_reminder\Helper;

/**
 * Helper for manage Drupal Session module's key.
 */
class SessionHelper {
  const SESSION_EXP_DATETIME = "session_reminder__exp_timestamp";

  /**
   * Set Session Expiring Datetime in session.
   *
   * @param int|null $timestamp
   *   Timestamp.
   *
   * @return void
   *   No return.
   */
  public static function setExpTimestamp(int|null $timestamp = NULL): void {
    /** @var \Symfony\Component\HttpFoundation\Session\SessionInterface $session */
    $session = \Drupal::service('session');
    $session->set(self::SESSION_EXP_DATETIME, $timestamp);
  }

  /**
   * Get Session Expiring Datetime from session.
   *
   * @return int|null
   *   Session Expiring Datetime from session.
   */
  public static function getExpTimestamp(): int|null {
    /** @var \Symfony\Component\HttpFoundation\Session\SessionInterface $session */
    $session = \Drupal::service('session');
    if ($session->has(self::SESSION_EXP_DATETIME)) {
      return $session->get(self::SESSION_EXP_DATETIME);
    }
    else {
      // This condition is useful for showing modal accordly in case
      // of user already logged while enabling module.
      $user = \Drupal::currentUser();

      if ($user?->getLastAccessedTime()) {
        return $user->getLastAccessedTime() + SessionReminderHelper::getCookieLifetime();
      }
    }

    return NULL;
  }

  /**
   * Destroy SessionReminder session.
   *
   * @return void
   *   No return values.
   */
  public static function destroy(): void {
    /** @var \Symfony\Component\HttpFoundation\Session\SessionInterface $session */
    $session = \Drupal::service('session');
    if ($session->has(self::SESSION_EXP_DATETIME)) {
      $session->remove(self::SESSION_EXP_DATETIME);
    }
  }

}
