<?php

namespace Drupal\session_reminder\Helper;

/**
 * Helper for generic Session Reminder utilities.
 */
class SessionReminderHelper {

  /**
   * Check if user is authenticated and Role enabled to show modal.
   *
   * @return bool
   *   User can show the modal
   */
  public static function userEnabled() {
    $user = \Drupal::currentUser();
    $authenticated = $user->isAuthenticated();
    $expTimestamp = SessionHelper::getExpTimestamp();

    if ($authenticated && !empty($expTimestamp)) {
      // If not setted start session timestamp on hook login, not load modal.
      $roles = array_flip($user->getRoles());
      $roles['all'] = TRUE;
      $enabledRoles = \Drupal::config('session_reminder.settings')
        ->get('roles');

      return (count(array_intersect_key($roles, $enabledRoles)) >= 1);
    }

    return FALSE;
  }

  /**
   * Get Cookie Lifetime defined in services.yml.
   */
  public static function getCookieLifetime() {
    return ini_get("session.cookie_lifetime");
  }

}
